OPA
===

.. currentmodule:: xeofs.single

.. autoclass:: OPA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~OPA.__init__
      ~OPA.components
      ~OPA.compute
      ~OPA.decorrelation_time
      ~OPA.deserialize
      ~OPA.filter_patterns
      ~OPA.fit
      ~OPA.fit_transform
      ~OPA.get_params
      ~OPA.get_serialization_attrs
      ~OPA.inverse_transform
      ~OPA.load
      ~OPA.save
      ~OPA.scores
      ~OPA.serialize
      ~OPA.transform
   
   

   
   
   